@@ -186,8 +186,14 @@ def upload_loop():
                                         })
                 moved = 1
                 logger.info("upload successful", extra={"metric_tag": "video_moved", "video_start_time": ts})
-                os.remove(name)
-                os.remove(mp4_name)
+                try:
+                    os.remove(name)
+                except FileNotFoundError:
+                    pass  # file disappeared?
+                try:
+                    os.remove(mp4_name)
+                except FileNotFoundError:
+                    pass  # file disappeared?
             except Exception as err:
                 moved = 0
                 logger.exception(err)
